@@ -35,14 +35,14 @@ import (
 
 	"github.com/fogleman/gg"
 
-	"pkg.deepin.io/lib/graphic"
-	"pkg.deepin.io/lib/log"
+	"github.com/linuxdeepin/go-lib/graphic"
+	"github.com/linuxdeepin/go-lib/log"
 
 	"github.com/disintegration/imaging"
 
-	"pkg.deepin.io/dde/api/grub_theme/font"
-	tt "pkg.deepin.io/dde/api/grub_theme/themetxt"
-	"pkg.deepin.io/lib/locale"
+	"github.com/linuxdeepin/dde-api/grub_theme/font"
+	tt "github.com/linuxdeepin/dde-api/grub_theme/themetxt"
+	"github.com/linuxdeepin/go-lib/locale"
 )
 
 const (
@@ -119,19 +119,19 @@ func adjustBackground(themeOutputDir string, img image.Image) (image.Image, erro
 	return img0, nil
 }
 
-func adjustResourcesOsLogos(themeInputDir, themeOutputDir string, width, height int) {
+func adjustResourcesOsLogos(themeInputDir, themeOutputDir string, width, height int) error {
 	srcDir := filepath.Join(themeInputDir, "resources/os-logos")
 	fileInfoList, err := ioutil.ReadDir(srcDir)
 	if err != nil {
 		logger.Warning(err)
-		return
+		return err
 	}
 
 	outDir := filepath.Join(themeOutputDir, "icons")
 	err = os.Mkdir(outDir, 0755)
 	if err != nil {
 		logger.Warning(err)
-		return
+		return err
 	}
 
 	for _, fileInfo := range fileInfoList {
@@ -149,8 +149,10 @@ func adjustResourcesOsLogos(themeInputDir, themeOutputDir string, width, height
 		err = convertSvg(file, outFile, width, height)
 		if err != nil {
 			logger.Warning(err)
+			return err
 		}
 	}
+	return nil
 }
 
 const (
@@ -173,8 +175,8 @@ func getFontSize(screenWidth int, screenHeight int) int {
 	return round(y)
 }
 
-func getScreenSizeFromGrubParams() (w, h int, err error) {
-	params, err := loadGrubParams()
+func getScreenSizeFromGrubParams(grubParamsFilePath string) (w, h int, err error) {
+	params, err := loadGrubParams(grubParamsFilePath)
 	if err != nil {
 		return
 	}
@@ -349,7 +351,10 @@ func adjustThemeNormal() error {
 
 			iconWidth, _ := comp.GetPropInt("icon_width")
 			iconHeight, _ := comp.GetPropInt("icon_height")
-			adjustResourcesOsLogos(themeInputDir, themeOutputDir, iconWidth, iconHeight)
+			err = adjustResourcesOsLogos(themeInputDir, themeOutputDir, iconWidth, iconHeight)
+			if err != nil {
+				logger.Warning(err)
+			}
 
 		} else if comp.Type == tt.ComponentTypeLabel {
 			adjustLabel(themeOutputDir, comp, vars)
@@ -361,7 +366,9 @@ func adjustThemeNormal() error {
 	if err != nil {
 		return err
 	}
-	defer themeOutputFh.Close()
+	defer func() {
+		_ = themeOutputFh.Close()
+	}()
 	bw := bufio.NewWriter(themeOutputFh)
 	// write head
 	_, err = fmt.Fprintf(bw, "#version:%d\n", VERSION)
@@ -445,7 +452,9 @@ func adjustThemeFallback() error {
 	if err != nil {
 		return err
 	}
-	defer themeOutputFh.Close()
+	defer func() {
+		_ = themeOutputFh.Close()
+	}()
 	bw := bufio.NewWriter(themeOutputFh)
 	// write head
 	_, err = fmt.Fprintf(bw, "#version:%d\n", VERSION)
@@ -495,7 +504,7 @@ func main() {
 
 	if optScreenWidth == 0 || optScreenHeight == 0 {
 		var err error
-		optScreenWidth, optScreenHeight, err = getScreenSizeFromGrubParams()
+		optScreenWidth, optScreenHeight, err = getScreenSizeFromGrubParams(grubParamsFile)
 		if err != nil {
 			logger.Debug(err)
 			optScreenWidth = 1024
@@ -565,12 +574,12 @@ func cleanupThemeOutputDir(dir string) {
 	for _, fileInfo := range fileInfoList {
 		filename := filepath.Join(dir, fileInfo.Name())
 		if fileInfo.IsDir() {
-			os.RemoveAll(filename)
+			_ = os.RemoveAll(filename)
 		} else {
 			if fileInfo.Name() == "background_source" {
 				// do not delete it
 			} else {
-				os.Remove(filename)
+				_ = os.Remove(filename)
 			}
 		}
 	}
@@ -605,6 +614,7 @@ func genPF2Font(themeOutputDir, fontFile string, faceIndex, size int) (*font.Fac
 	fontBaseName = fmt.Sprintf("ag-%s-%d-%d.pf2", fontBaseName, faceIndex, size)
 	output := filepath.Join(themeOutputDir, fontBaseName)
 
+	// #nosec G204
 	cmd := exec.Command("grub-mkfont", "-i", faceIndexStr,
 		"-s", sizeStr, "-o", output, fontFile)
 	logger.Debugf("$ grub-mkfont -i %d -s %d -o %s %s",
