@@ -4,7 +4,7 @@ import (
 	"image"
 	"path/filepath"
 
-	"pkg.deepin.io/dde/api/theme_thumb/common"
+	"github.com/linuxdeepin/dde-api/theme_thumb/common"
 )
 
 const (
